@@ -8,20 +8,20 @@ import warnings
 
 import fiona
 import folium
-from folium import IFrame
 import geojson
 import geopandas as gpd
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
 import rasterio
+from folium import IFrame
 from rasterio import mask
 from rasterio.enums import Resampling
 from rasterio.vrt import WarpedVRT
-from shapely.geometry import shape, MultiPoint
+from shapely.geometry import MultiPoint, shape
 from sklearn.ensemble import IsolationForest
 
-from classifier.utils.general import progress, impute_values
+from classifier.utils.general import impute_values, progress
 from classifier.utils.raster import raster_warp_dst
 
 # Set Logging levels on Rasterio and Fiona to not get too many logging msg
@@ -32,18 +32,18 @@ FIONA_LOGGER.setLevel(logging.CRITICAL)
 DATAPREP_LOGGER = logging.getLogger(__name__)
 
 
-def check_training_data_nodata(dataset, config_dict):
+def check_training_data_nodata(dataset, config):
     """
     Check whether there is nodata in the training dataset
     Args:
         dataset (DataFrame or Numpy Array):Dataset with gathered sample data
-        config_dict (dict): CLI configuration dictionary
+        config (Configuration) contains config
 
     Returns:
         dataset without nans
 
     """
-    #Check if nans are present
+    # Check if nans are present
     contains_nans = False
     if isinstance(dataset, np.ndarray):
         if np.isnan(dataset).any():
@@ -52,7 +52,7 @@ def check_training_data_nodata(dataset, config_dict):
         if dataset.isnull().values.any():
             contains_nans = True
 
-    if contains_nans and not config_dict['app_imputation']:
+    if contains_nans and not config.app.imputation:
         DATAPREP_LOGGER.warning("""The sampled dataset contains nan's.
         Imputation is set to False so all rows containing NaNs will be 
         deleted. If you want to prevent this from happening, please set the 
@@ -64,11 +64,11 @@ def check_training_data_nodata(dataset, config_dict):
             dataset = dataset.dropna(how='any')
     elif contains_nans:
         DATAPREP_LOGGER.info("Found missing values. Doing imputation...")
-        if config_dict['app_imputation_strategy'] == 'randomforest':
+        if config.app.imputation_strategy == 'randomforest':
             DATAPREP_LOGGER.error("Random Forest strategy only allowed for "
                                   "timeseries, please select another strategy")
             sys.exit()
-        dataset = impute_values(dataset, config_dict)
+        dataset = impute_values(dataset, config)
     return dataset
 
 
@@ -127,7 +127,6 @@ def gather_samples_for_roi(roi, rasters, warp_dst):
                         [roi["geometry"]],
                         crop=True)
                     raster_subset = vrt.read(window=window)
-
             # rasterio convention: outside shape=True, inside=False. We invert.
             samples_per_raster = raster_subset[:, ~selection]
             roi_values.append(samples_per_raster)
@@ -139,7 +138,7 @@ def gather_samples_for_roi(roi, rasters, warp_dst):
     return roi_values
 
 
-def gather_samples(rasters, rois, bandnames, out_dir, config_dict):
+def gather_samples(rasters, rois, bandnames, out_dir, config):
     """Takes a raster reference from the first raster, loops over all rois and
        returns two lists of equal lenght for samples and labels.s
 
@@ -148,7 +147,7 @@ def gather_samples(rasters, rois, bandnames, out_dir, config_dict):
             rois (str): path to fiona supported regions of interest file
             bandnames (list): list of names of the input rasters and bands
             out_dir (str): path to the output directory
-            config_dict (dict): The cli arguments
+            config (Configuration) contains config
         Returns:
             Dataset (DataFrame): Gathered Samples
 
@@ -156,8 +155,8 @@ def gather_samples(rasters, rois, bandnames, out_dir, config_dict):
     sample_labels = []
     all_samples = []
     roi_dict = {}
-    if config_dict['su_boxplots']:
-        #Boxplot Directory
+    if config.supervised.boxplots:
+        # Boxplot Directory
         roi_bp_dir = out_dir + '/roi_boxplots/'
         os.mkdir(roi_bp_dir)
 
@@ -180,10 +179,10 @@ def gather_samples(rasters, rois, bandnames, out_dir, config_dict):
             if roi_samples is not None:
                 sample_count += roi_samples.shape[0]
 
-                all_samples.append(roi_samples.astype(np.float))
+                all_samples.append(roi_samples.astype(float))
                 roi_id = int(roi['properties']['id'])
                 sample_labels += len(roi_samples) * [roi_id]
-                if config_dict['su_boxplots']:
+                if config.supervised.boxplots:
                     polygon_boxplot(roi_samples,
                                     bandnames,
                                     roi_id,
@@ -194,29 +193,29 @@ def gather_samples(rasters, rois, bandnames, out_dir, config_dict):
         all_samples = np.concatenate(all_samples, axis=0)
         sample_labels = np.asarray(sample_labels)
 
-    all_samples = check_training_data_nodata(all_samples, config_dict)
+    all_samples = check_training_data_nodata(all_samples, config)
 
     dataset = pd.DataFrame(all_samples, columns=bandnames).join(
         pd.DataFrame({'class': sample_labels}))
     DATAPREP_LOGGER.debug("Got: %i samples in total.", len(dataset))
 
-    if config_dict['su_remove_outliers']:
+    if config.supervised.remove_outliers:
         dataset = outlier_removal(dataset)
-    if config_dict['su_boxplots']:
+    if config.supervised.boxplots:
         boxplot(dataset, out_dir)
         folium_map_boxplots(roi_dict, roi_bp_dir)
 
     return dataset
 
 
-def createdataset(rasters, rois, workspace, config_dict):
+def createdataset(rasters, rois, workspace, config):
     """
     Create the entire dataset based on rasters and rois
     Args:
         rasters (list): the input rasters
         rois (str): The ogr vector file containing polygons
         workspace (str): Path to workspace
-        config_dict (dict): The cli arguments
+        config (Configuration) contains config
     Returns:
         dataset
     """
@@ -226,7 +225,8 @@ def createdataset(rasters, rois, workspace, config_dict):
                           rois,
                           bandnames,
                           workspace,
-                          config_dict)
+                          config)
+
 
 def polygon_boxplot(roi_values, bandnames, class_title, roi_bp_dir, roi_number):
     """Make a simple boxplot for a polygon from the training data
@@ -239,7 +239,7 @@ def polygon_boxplot(roi_values, bandnames, class_title, roi_bp_dir, roi_number):
             roi_number (int/str): The identifier of the roi to use in filename
 
     """
-    #Bunch of settings to make the boxplots look nicer
+    # Bunch of settings to make the boxplots look nicer
     plt.rcParams['xtick.labelsize'] = 4
     plt.rcParams['ytick.labelsize'] = 4
     plt.rcParams['axes.labelsize'] = 4
@@ -268,6 +268,7 @@ def polygon_boxplot(roi_values, bandnames, class_title, roi_bp_dir, roi_number):
                 dpi=300)
     plt.close()
 
+
 def boxplot(samples, output_dir):
     """Boxplot of all samples
 
@@ -308,7 +309,7 @@ def add_polygons_to_map(gdf, folium_map, png_dir):
     for items in gdf.iterrows():
         geom_geojson = geojson.Feature(geometry=items[1]['geometry'],
                                        properties={}
-                                      )
+                                       )
         points = geom_geojson['geometry']['coordinates']
         image_link = f"{png_dir}/{items[1]['id']}.png"
         with base64.b64encode(open(image_link, 'rb').read()) as src:
@@ -323,7 +324,7 @@ def add_polygons_to_map(gdf, folium_map, png_dir):
                                  color='#3186cc',
                                  fill=True,
                                  fill_color='#3186cc'
-                                )
+                                 )
         folium_map.add_child(marker)
     return folium_map
 
@@ -341,7 +342,7 @@ def add_baselayers(folium_map):
     folium.TileLayer(name='Google Satellite',
                      tiles='https://mt1.google.com/vt/lyrs=s&x={x}&y={y}&z={z}',
                      attr='Google Imagery'
-                    ).add_to(folium_map)
+                     ).add_to(folium_map)
     folium.TileLayer(name='Esri Satellite',
                      tiles='https://server.arcgisonline.com/ArcGIS/rest'
                            '/services/World_Imagery/MapServer/tile/{z}/{y}/{'
@@ -350,6 +351,7 @@ def add_baselayers(folium_map):
     folium.LayerControl().add_to(folium_map)
     return folium_map
 
+
 def folium_map_boxplots(roi_dict, out_dir):
     """Main function to make folium map with boxplots
 
@@ -360,16 +362,17 @@ def folium_map_boxplots(roi_dict, out_dir):
     """
     indices = list(roi_dict.keys())
     geoms = list(roi_dict.values())
-    gdf = gpd.GeoDataFrame({'id': indices, 'geometry':geoms})
+    gdf = gpd.GeoDataFrame({'id': indices, 'geometry': geoms})
     center_point = MultiPoint(gdf.centroid).centroid
     lat, lon = center_point.y, center_point.x
     folium_map = folium.Map(location=[lat, lon],
                             zoom_start=9,
-                           )
+                            )
     folium_map = add_baselayers(folium_map)
     folium_map = add_polygons_to_map(gdf, folium_map, out_dir)
     folium_map.save(out_dir+'/all_rois.html')
 
+
 def outlier_removal(samples):
     """Outlier removal from samples using Isolation Forest
 
@@ -380,7 +383,6 @@ def outlier_removal(samples):
             samples (DataFrame)
     """
     DATAPREP_LOGGER.info("Now checking for outliers")
-
     cols = [x for x in samples.columns if x != 'class']
     if_model = IsolationForest(contamination='auto')
 
@@ -406,7 +408,6 @@ def outlier_removal(samples):
     return samples[samples['inlier'] > 0][cols_to_return]
 
 
-
 def class_counts(samples):
     """Prints the number of pixels removed after outlier removal
 
