@@ -1,15 +1,14 @@
 """File containing all model classes necessary to run the classifier"""
 import logging
-import os
+from pathlib import Path
 
 import matplotlib.pyplot as plt
+import numpy as np
 import pandas as pd
-from sklearn.ensemble import IsolationForest
-from sklearn.ensemble import RandomForestClassifier
+from sklearn.ensemble import IsolationForest, RandomForestClassifier
 from sklearn.model_selection import RandomizedSearchCV
 from xgboost import XGBClassifier
 
-
 # initiate logger
 MODELS_LOGGER = logging.getLogger(__name__)
 
@@ -18,16 +17,16 @@ class BaseMixin:
     """A mixin class for all models. This allows for each algorithm to use the
     optimise and plotting functions"""
 
-    def plot_time_vs_accuracy(self, out_dir):
+    def plot_time_vs_accuracy(self, out_dir: Path) -> None:
         """Plotting the training time vs the accuracy.
 
         Args:
             time (array): The time values to plot
             accuracy(array) The accuracy values to plot
-            out_dir: THe output directory (path)
+            out_dir (Path): Output directory
 
         Returns:
-            Nothing
+            None
         """
         time = self.cv_df['mean_fit_time']
         accuracy = self.cv_df['mean_test_score']
@@ -37,25 +36,28 @@ class BaseMixin:
         axis.set_xlabel("Time (s)")
         axis.set_ylabel("Accuracy (-) ")
         plt.tight_layout()
-        plt.savefig(os.path.join(out_dir, 'Optimisation_time.png'), dpi=300)
+        plt.savefig(out_dir, 'Optimisation_time.png', dpi=300)
 
-    def random_optimise(self, trainx, trainy, out_dir,
-                        optimise_iters=10):
+    def random_optimise(
+            self, trainx: np.ndarray, trainy: np.ndarray, out_dir: Path,
+            optimise_iters=10):
         """Optimization of a parameter space using random samples from the
         parameter space
 
         Args:
-            trainx (array) :   Training dataset features (X-values)
-            trainy (array) :   Training dataset outputs (class names, y values)
-            out_dir (string):  The output directory path
-            optimise_iters (int)  The number of iterations for the optimisation.
+            trainx (np.ndarray):   Training dataset features (X-values)
+            trainy (np.ndarray):   Training dataset outputs
+                (class names, y values)
+            out_dir (Path):  The output directory path
+            optimise_iters (int): The number of iterations for the optimisation.
 
         Returns:
             The best performing parameter combination  (dict)
 
         """
         MODELS_LOGGER.info("\n####-----Optimisation----#####\n")
-        MODELS_LOGGER.info("Starting Optimisation. This might take a while....")
+        MODELS_LOGGER.info(
+            "Starting Optimisation. This might take a while....")
         clf = RandomizedSearchCV(self,
                                  self.parameter_matrix,
                                  verbose=0,
@@ -64,7 +66,7 @@ class BaseMixin:
                                  return_train_score=True,
                                  n_jobs=-1,
                                  n_iter=optimise_iters
-                                )
+                                 )
         clf.fit(trainx, trainy)
         MODELS_LOGGER.info("Best estimator: \n %s", clf.best_estimator_)
         self.cv_df = pd.DataFrame(clf.cv_results_)
@@ -79,6 +81,8 @@ class BaseMixin:
         return parameter_set
 
 # pylint: disable=too-many-ancestors
+
+
 class RandomForest(RandomForestClassifier, BaseMixin):
     """RandomForest class; child of RandomForestClassifier from sk-learn"""
 
@@ -116,18 +120,17 @@ class XGBoost(XGBClassifier, BaseMixin):
         self.parameter_matrix = {'learning_rate': [0.1, 0.2, 0.3],
                                  "n_estimators": [10, 20, 50, 100, 200],
                                  'max_depth': [1, 3, 5, 10]
-                                }
+                                 }
 
 
 class SingleClass(IsolationForest, BaseMixin):
 
     """Singleclass class, child of IsolationForest model from sk-learn"""
 
-
     def __init__(self):
         super().__init__()
 
         self.parameter_matrix = {"n_estimators": [10, 20, 50, 100, 200],
                                  'max_samples': ['auto', 10, 50, 100, 200],
                                  "max_features": [0.1, 0.3, 0.5, 1.0]
-                                }
+                                 }
