@@ -1,15 +1,14 @@
 "Training module for classifier"
 import numpy as np
-
 from sklearn.model_selection import train_test_split
 
-from classifier.utils.general import get_available_model_args
 from classifier import __version__ as classifier_version
 from classifier.settings import ALGORITHM_DICT
+from classifier.utils.general import get_available_model_args
 
 
 def train_dataset(dataset, algorithm, out_dir,
-                  config_dict):
+                  config):
     """Train the model using a dataset
 
     Args:
@@ -18,7 +17,7 @@ def train_dataset(dataset, algorithm, out_dir,
                         \numbers
         algorithm       The algorithm name
         out_dir         Path where to write dataset file
-        config_dict     command line arguments dictionary
+        config (Configuration) contains config
 
     Returns:
         model_dict      A dictionary containing the name, model and label
@@ -32,7 +31,7 @@ def train_dataset(dataset, algorithm, out_dir,
     model, xcols, test = init_model_and_train(dataset,
                                               algorithm,
                                               out_dir,
-                                              config_dict)
+                                              config)
 
     model_dict = {'app_algorithm': algorithm,
                   'model': model,
@@ -41,6 +40,7 @@ def train_dataset(dataset, algorithm, out_dir,
                   'version': classifier_version}
     return model_dict, test
 
+
 def set_model_parameters(algorithm, algorithm_args, y_train):
     """
     Set the model parameters
@@ -62,14 +62,16 @@ def set_model_parameters(algorithm, algorithm_args, y_train):
         model.set_params(**{'objective': 'binary:logistic'})
     return model
 
+
 def init_model_and_train(dataset, algorithm, out_dir,
-                         config_dict):
+                         config):
     """
     Set the model parameters and train it
     Args:
         dataset (Array) : The dataset for input in the model (array)
         algorithm: The algorithm to use
         out_dir: The output directory
+        config (Configuration) contains config
 
     Returns:
         Trained model
@@ -77,28 +79,29 @@ def init_model_and_train(dataset, algorithm, out_dir,
         test dataset
 
     """
-    optimize = config_dict['su_optimize']
-    optimize_iters = config_dict['su_optimize_number']
-    test_size = config_dict['acc_testfraction']
+    optimize = config.supervised.optimization.optimize
+    optimize_iters = config.supervised.optimization.optimize_number
+    test_size = config.accuracy.testfraction
     train, test = train_test_split(dataset, test_size=test_size)
     xcols = [x for x in train.columns if 'class' not in x]
     x_train = train[xcols].values
-    y_train = np.ravel(train[[x for x in train.columns if 'class' in x]].values)
+    y_train = np.ravel(
+        train[[x for x in train.columns if 'class' in x]].values)
     # Get the model and fit
     model = set_model_parameters(algorithm, {}, y_train)
     if optimize:
         try:
             model.parameter_matrix = {
-                'max_features': config_dict['su_search_max_features'],
-                'max_depth': config_dict['su_search_max_depth'],
-                'max_leaf_nodes': config_dict['su_search_max_leaf_nodes'],
-                'n_estimators': config_dict['su_search_n_estimators']}
+                'max_features': config.supervised.optimization.max_features,
+                'max_depth': config.supervised.optimization.max_depth,
+                'max_leaf_nodes': config.supervised.optimization.max_leaf_nodes,
+                'n_estimators': config.supervised.optimization.n_estimators}
             algorithm_args = model.random_optimise(
                 x_train,
                 y_train,
                 out_dir,
                 optimize_iters
-                )
+            )
             model = set_model_parameters(algorithm, algorithm_args, y_train)
         except AttributeError as no_attribute:  # if there is no param. matrix
             raise AttributeError from no_attribute
